==> apache-eventmesh-1.9.0-source.tar.gz: apache-eventmesh-1.9.0-src/eventmesh-common/src/test/java/org/apache/eventmesh/common/EventMeshThreadFactoryTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.eventmesh.common;

import org.junit.Assert;
import org.junit.Test;

public class EventMeshThreadFactoryTest {

    @Test
    public void testGetThreadNamePrefix() {
        final String threadNamePrefix = "threadNamePrefix";
        EventMeshThreadFactory factory = new EventMeshThreadFactory(threadNamePrefix, false);
        Assert.assertEquals(threadNamePrefix, factory.getThreadNamePrefix());
    }

    @Test
    public void testNewThread() {
        final String threadNamePrefix = "threadNamePrefix";
        EventMeshThreadFactory factory = new EventMeshThreadFactory(threadNamePrefix, true);
        Thread t = factory.newThread(() -> {

        });
        Assert.assertNotNull(t);
        Assert.assertEquals(threadNamePrefix + "-1", t.getName());
        Assert.assertTrue(t.isDaemon());
    }
}

==> apache-eventmesh-1.10.0-source.tar.gz: apache-eventmesh-1.10.0-src/eventmesh-common/src/test/java/org/apache/eventmesh/common/EventMeshThreadFactoryTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.eventmesh.common;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

public class EventMeshThreadFactoryTest {

    @Test
    public void testGetThreadNamePrefix() {
        final String threadNamePrefix = "threadNamePrefix";
        EventMeshThreadFactory factory = new EventMeshThreadFactory(threadNamePrefix, false);
        Assertions.assertEquals(threadNamePrefix, factory.getThreadNamePrefix());
    }

    @Test
    public void testNewThread() {
        final String threadNamePrefix = "threadNamePrefix";
        EventMeshThreadFactory factory = new EventMeshThreadFactory(threadNamePrefix, true);
        Thread t = factory.newThread(() -> {

        });
        Assertions.assertNotNull(t);
        Assertions.assertEquals(threadNamePrefix + "-1", t.getName());
        Assertions.assertTrue(t.isDaemon());
    }
}
